@@ -131,6 +131,10 @@ def read_in_sheet(templt_name, file_path_in):
     # pull in the column definitions from the excel sheet
     column_read_dict = pd.read_excel(file_path_in,
                                      sheet_name="column_definitions", header=0,
-                                     index_col=0, engine='openpyxl').to_dict('index')
+                                     index_col=0, engine='openpyxl')
+    try:
+        column_read_dict = column_read_dict.to_dict('index')
+    except:
+        raise NameError(column_read_dict)
 
     return (column_read_dict, sheet_dict, description_info, collection_info)
